"""调度器"""
import logging
import argparse
import pathlib
from vxutils import vxtime, logger, to_timestring, vxToolBox

from vxsched.context import vxContext
from vxsched.event import vxEvent, vxTrigger, TriggerStatus
from vxsched.core import (
    vxChannel,
    vxLocalEventBroker,
    vxEventBroker,
    vxSched,
    init_scheduler,
    vxscheduler,
)
from vxsched.triggers import (
    vxDailyTrigger,
    vxWeeklyTrigger,
    vxIntervalTrigger,
    vxOnceTrigger,
)

VERSION = "1.0.3"


def _record_factory(*args, **kwargs):
    """记录工厂"""
    record = old_factory(*args, **kwargs)
    format_str = "%F %T.%f" if vxtime.status == "LIVING" else "%F %T"
    record.quant_time = to_timestring(vxtime.now(), format_str)
    return record


old_factory = logging.getLogRecordFactory()
logging.setLogRecordFactory(_record_factory)

_DEFAULT_QUANT_FORMAT = (
    "%(quant_time)s %(module)s.%(funcName)s[%(lineno)d] %(levelname)s === %(message)s"
)

_formatter = logging.Formatter(_DEFAULT_QUANT_FORMAT)
for handler in logger.handlers:
    handler.setFormatter(_formatter)


__all__ = [
    "vxContext",
    "vxEvent",
    "vxEventBroker",
    "vxLocalEventBroker",
    "vxTrigger",
    "TriggerStatus",
    "vxOnceTrigger",
    "vxDailyTrigger",
    "vxWeeklyTrigger",
    "vxIntervalTrigger",
    "vxChannel",
    "VERSION",
    "vxSched",
    "vxscheduler",
]
