"""共享内存SyncManager类"""


from multiprocessing.managers import BaseManager
from vxutils import to_binary, logger, vxtime
from vxsched.core import vxChannel
from vxsched.core import vxLocalEventBroker, vxEventBroker
from vxsched.event import vxEvent
from vxsched.triggers import vxOnceTrigger, vxIntervalTrigger

logger.setLevel("DEBUG")


class vxShareMemoryEventBrokerServer(BaseManager):
    """共享内存EventBroker"""


event_broker = vxLocalEventBroker()

vxShareMemoryEventBrokerServer.register("get_broker", lambda: event_broker)


class vxShareMemoryEventBroker(vxEventBroker):
    """共享内存event broker"""

    def __init__(self, host: str = "", port: int = 5555, authkey: str = "") -> None:
        super().__init__()

        authkey = to_binary(authkey)

        server = vxShareMemoryEventBrokerServer(address=(host, port), authkey=authkey)
        server.connect()
        self._broker = server.get_broker()

    def get(self, channel_name: str) -> vxEvent:
        return self._broker.get(channel_name)

    def put(self, channel_name: str, event: vxEvent) -> None:
        return self._broker.put(channel_name, event)

    def get_first_event_trigger_dt(self, channel_name: str) -> float:
        return self._broker.get_first_event_trigger_dt(channel_name)


if __name__ == "__main__":
    from queue import Empty

    broker = vxShareMemoryEventBroker()
    channel = vxChannel("test", broker)
    for _ in range(3):
        trigger = vxIntervalTrigger(1)
        channel.put("test", 1, trigger=trigger)

    vxtime.sleep(3)
    print(vxtime.now())
    print("=" * 60)

    for i in range(1, 10):
        print(f"第{i}个")
        try:
            event1 = channel.get(vxtime.now())
            print(event1)
        except Empty:
            logger.info("空队列")
    print("=" * 60)

    # * for _ in range(10):
    # *     try:
    # *         event1 = channel2.get(vxtime.now() + 10)
    # *         print(event1)
    # *     except Empty:
    # *         logger.info("空队列")
